/*
 *
 * Copyright  2004-2006, University of Washington, 
 * Department of Computer Science and Engineering. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer. 
 * 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 *
 * 3. Neither name of the University of Washington, Department of Computer 
 * Science and Engineering nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE FOR 
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 *
 */


package cse466.packets;


public class AdjustGlobalsPacket extends CSE466Packet 
{
	public int node0;
	public int minListen;
	public int maxListen;
	public int Threshold;
	public int minInfectionLength;
	public int maxInfectionLength;
	public int minImmuneLength;
	public int maxImmuneLength;
	public int minRebirthDelay;
	public int maxRebirthDelay;
	public int minPointValue;
	public int repetition;
	public int silence;
	public int transmitPower;
	public int startledHopCount;
	public int infectiousness;
	public int chanceRecovery;
	public int chanceBornInfected;

	public AdjustGlobalsPacket() 
	{
		node0 = 0;
		minListen = 2000;
		maxListen = 15000;
		Threshold = 600;
		minPointValue = 100;
		repetition = 3;
		silence = 10;
		transmitPower = 0x0f;
		startledHopCount = 1;
	}

	public int getProperAMType()
	{
		return 50;
	}

	public byte[] setFromBytes(byte[] fromArray)
	{
		byte[] me = super.setFromBytes(fromArray);
		node0               = bytesToInt(me[ 0], me[ 1]);
		minListen			= bytesToInt(me[ 2], me[ 3]);
		maxListen			= bytesToInt(me[ 4], me[ 5]);
		Threshold			= bytesToInt(me[ 6], me[ 7]);
		minInfectionLength	= bytesToInt(me[ 8], me[ 9]);
		maxInfectionLength	= bytesToInt(me[10], me[11]);
		minImmuneLength		= bytesToInt(me[12], me[13]);
		maxImmuneLength		= bytesToInt(me[14], me[15]);
		minRebirthDelay		= bytesToInt(me[16], me[17]);
		maxRebirthDelay		= bytesToInt(me[18], me[19]);
		minPointValue		= bytesToInt(me[20], me[21]);
		repetition			= me[22];
		silence				= me[23];
		transmitPower		= me[24];
		startledHopCount	= me[25];
		infectiousness		= me[26];
		chanceRecovery		= me[27];
		chanceBornInfected	= me[28];

		return subArray(me, 29);
	}

	protected byte[] getByteArray(byte[] childByteArray)
	{
		byte[] ret = new byte[childByteArray.length + 29];
		ret[ 0] = intToLSB(node0);
		ret[ 1] = intToMSB(node0);
		ret[ 2] = intToLSB(minListen);
		ret[ 3] = intToMSB(minListen);
		ret[ 4] = intToLSB(maxListen);
		ret[ 5] = intToMSB(maxListen);
		ret[ 6] = intToLSB(Threshold);
		ret[ 7] = intToMSB(Threshold);
		ret[ 8] = intToLSB(minInfectionLength);
		ret[ 9] = intToMSB(minInfectionLength);
		ret[10] = intToLSB(maxInfectionLength);
		ret[11] = intToMSB(maxInfectionLength);
		ret[12] = intToLSB(minImmuneLength);
		ret[13] = intToMSB(minImmuneLength);
		ret[14] = intToLSB(maxImmuneLength);
		ret[15] = intToMSB(maxImmuneLength);
		ret[16] = intToLSB(minRebirthDelay);
		ret[17] = intToMSB(minRebirthDelay);
		ret[18] = intToLSB(maxRebirthDelay);
		ret[19] = intToMSB(maxRebirthDelay);
		ret[20] = intToLSB(minPointValue);
		ret[21] = intToMSB(minPointValue);
		ret[22] = (byte)repetition;
		ret[23] = (byte)silence;
		ret[24] = (byte)transmitPower;
		ret[25] = (byte)startledHopCount;
		ret[26] = (byte)infectiousness;
		ret[27] = (byte)chanceRecovery;
		ret[28] = (byte)chanceBornInfected;

		copyIntoArray(ret, childByteArray, 29);
		return super.getByteArray(ret);
	}

	public byte[] getByteArray()
	{
		return getByteArray(new byte[0]);
	}

	public void print()
	{
		super.print();
		System.out.println("AG     node0               : 0x" + Integer.toHexString(node0));
		System.out.println("AG     minListen           : 0x" + Integer.toHexString(minListen));
		System.out.println("AG     maxListen           : 0x" + Integer.toHexString(maxListen));
		System.out.println("AG     Threshold           : 0x" + Integer.toHexString(Threshold));    
		System.out.println("AG     minInfectionLength  : 0x" + Integer.toHexString(minInfectionLength));
		System.out.println("AG     maxInfectionLength  : 0x" + Integer.toHexString(maxInfectionLength));
		System.out.println("AG     minImmuneLength     : 0x" + Integer.toHexString(minImmuneLength));
		System.out.println("AG     maxImmuneLength     : 0x" + Integer.toHexString(maxImmuneLength));
		System.out.println("AG     minRebirthDelay     : 0x" + Integer.toHexString(minRebirthDelay));
		System.out.println("AG     maxRebirthDelay     : 0x" + Integer.toHexString(maxRebirthDelay));
		System.out.println("AG     minPointValue       : 0x" + Integer.toHexString(minPointValue));
		System.out.println("AG     repetition          : 0x" + Integer.toHexString(repetition));
		System.out.println("AG     silence             : 0x" + Integer.toHexString(silence));
		System.out.println("AG     transmitPower       : 0x" + Integer.toHexString(transmitPower));
		System.out.println("AG     startledHopCount    : 0x" + Integer.toHexString(startledHopCount));
		System.out.println("AG     infectiousness      : 0x" + Integer.toHexString(infectiousness));
		System.out.println("AG     chanceRecovery      : 0x" + Integer.toHexString(chanceRecovery));
		System.out.println("AG     chanceBornInfected  : 0x" + Integer.toHexString(chanceBornInfected));
	}

	public boolean equals(AdjustGlobalsPacket other) 
	{
		if(node0                != other.node0               ) return false;       
		if(minListen            != other.minListen           ) return false;    
		if(maxListen            != other.maxListen           ) return false;    
		if(Threshold            != other.Threshold           ) return false;    
		if(minInfectionLength   != other.minInfectionLength  ) return false;    
		if(maxInfectionLength   != other.maxInfectionLength  ) return false;    
		if(minImmuneLength      != other.minImmuneLength     ) return false;    
		if(maxImmuneLength      != other.maxImmuneLength     ) return false;    
		if(minRebirthDelay      != other.minRebirthDelay     ) return false;    
		if(maxRebirthDelay      != other.maxRebirthDelay     ) return false;    
		if(minPointValue        != other.minPointValue       ) return false;    
		if(repetition           != other.repetition          ) return false;    
		if(silence              != other.silence             ) return false;
		if(transmitPower        != other.transmitPower       ) return false;    
		if(startledHopCount     != other.startledHopCount    ) return false;
		if(infectiousness       != other.infectiousness      ) return false;
		if(chanceRecovery       != other.chanceRecovery      ) return false;
		if(chanceBornInfected   != other.chanceBornInfected  ) return false;
		return super.equals(other);
	}
}

