/*
 *
 * Copyright  2004-2006, University of Washington, 
 * Department of Computer Science and Engineering. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer. 
 * 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 *
 * 3. Neither name of the University of Washington, Department of Computer 
 * Science and Engineering nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE FOR 
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 *
 */

package cse466.packets;


public class CommandPacket extends CSE466Packet 
{

	public int node0;
	public int startAddr;
	public int endAddr;
	public int LED;
	public int song;
	public int healthState;

	public CommandPacket() 
	{
		node0 = 1;
		startAddr = 0;
		endAddr = 0xffff;
		LED = 0;
		song = -1;
		healthState = 0;
	}

	public int getProperAMType()
	{
		return 52;
	}


	public byte[] setFromBytes(byte[] fromArray)
	{
		fromArray = super.setFromBytes(fromArray);
		node0                = bytesToInt(fromArray[ 0], fromArray[ 1]);
		startAddr            = bytesToInt(fromArray[ 2], fromArray[ 3]);
		endAddr              = bytesToInt(fromArray[ 4], fromArray[ 5]);
		LED                  = bytesToInt(fromArray[ 6], fromArray[ 7]);
		song                 = bytesToInt(fromArray[ 8], fromArray[ 9]);
		healthState          = bytesToInt(fromArray[10], (byte)0);
		return subArray(fromArray,  11);
	}

	protected byte[] getByteArray(byte[] childByteArray)
	{
		byte[] ret = new byte[childByteArray.length + 11];
		ret[ 0] = intToLSB(node0);
		ret[ 1] = intToMSB(node0);
		ret[ 2] = intToLSB(startAddr);
		ret[ 3] = intToMSB(startAddr);
		ret[ 4] = intToLSB(endAddr);
		ret[ 5] = intToMSB(endAddr);
		ret[ 6] = intToLSB(LED);
		ret[ 7] = intToMSB(LED);
		ret[ 8] = intToLSB(song);
		ret[ 9] = intToMSB(song);
		ret[10] = (byte)healthState;
		copyIntoArray(ret, childByteArray,  11);
		return super.getByteArray(ret);
	}

	public byte[] getByteArray()
	{
		return getByteArray(new byte[0]);
	}

	public void print()
	{
		super.print();
		System.out.println("ST     node0               : 0x" + Integer.toHexString(node0));
		System.out.println("ST     startAddr           : 0x" + Integer.toHexString(startAddr));
		System.out.println("ST     endAddr             : 0x" + Integer.toHexString(endAddr));
		System.out.println("ST     LED                 : 0x" + Integer.toHexString(LED));
		System.out.println("ST     song                : 0x" + Integer.toHexString(song));
		System.out.println("ST     healthState         : 0x" + Integer.toHexString(healthState));
	}

	public boolean equals(CommandPacket other)
	{
		if(node0               != other.node0              ) return false;
		if(startAddr           != other.startAddr          ) return false;
		if(endAddr             != other.endAddr            ) return false;
		if(LED                 != other.LED                ) return false;
		if(song                != other.song               ) return false;
		if(healthState         != other.healthState        ) return false;
		return super.equals(other);
	}
}

