/*
 *
 * Copyright  2004-2006, University of Washington, 
 * Department of Computer Science and Engineering. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer. 
 * 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 *
 * 3. Neither name of the University of Washington, Department of Computer 
 * Science and Engineering nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE FOR 
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 *
 */

package cse466.packets;

public class SangSongPacket extends CSE466Packet 
{
	public int transmittingNodeNum;
	public int sequenceNum;
	public int songNum;
	public int healthState;
	public int immuneSystemStrength;
	public int mutationCount;
	public int mutationAmount;
	public int minImmuneRange;
	public int maxImmuneRange;

	public SangSongPacket() 
	{
		transmittingNodeNum = 0;
		sequenceNum = 1;
		songNum = 0;
		healthState = 0;
		immuneSystemStrength = 0;
		mutationCount = 0;
		mutationAmount = 0;
		minImmuneRange = 0;
		maxImmuneRange = 0;
	}

	public int getProperAMType()
	{
		return 42;
	}


	public byte[] setFromBytes(byte[] fromArray)
	{
		fromArray = super.setFromBytes(fromArray);
		transmittingNodeNum   = bytesToInt(fromArray[ 0], fromArray[ 1]);
		sequenceNum           = bytesToInt(fromArray[ 2], fromArray[ 3]);
		songNum               = bytesToInt(fromArray[ 4], fromArray[ 5]);
		healthState           = bytesToInt(fromArray[ 6], (byte)0);
		immuneSystemStrength  = bytesToInt(fromArray[ 7], (byte)0);
		mutationCount         = bytesToInt(fromArray[ 8], (byte)0);
		mutationAmount        = bytesToInt(fromArray[ 9], (byte)0);
		minImmuneRange        = bytesToInt(fromArray[10], (byte)0);
		maxImmuneRange        = bytesToInt(fromArray[11], (byte)0);
		return subArray(fromArray, 12);
	}

	protected byte[] getByteArray(byte[] childByteArray)
	{
		byte[] ret = new byte[childByteArray.length + 24];
		ret[ 0] = intToLSB(transmittingNodeNum);
		ret[ 1] = intToMSB(transmittingNodeNum);
		ret[ 2] = intToLSB(sequenceNum);
		ret[ 3] = intToMSB(sequenceNum);
		ret[ 4] = intToLSB(songNum);
		ret[ 5] = intToMSB(songNum);
		ret[ 6] = (byte)healthState;
		ret[ 7] = (byte)immuneSystemStrength;
		ret[ 8] = (byte)mutationCount;
		ret[ 9] = (byte)mutationAmount;
		ret[10] = (byte)minImmuneRange;
		ret[11] = (byte)maxImmuneRange;

		copyIntoArray(ret, childByteArray, 12);
		return super.getByteArray(ret);
	}

	public byte[] getByteArray()
	{
		return getByteArray(new byte[0]);
	}

	public void print()
	{
		super.print();
		System.out.println("SP     transmittingNodeNum  : 0x" + Integer.toHexString(transmittingNodeNum));
		System.out.println("SP     sequenceNum          : 0x" + Integer.toHexString(sequenceNum));
		System.out.println("SP     songNum              : 0x" + Integer.toHexString(songNum));
		System.out.println("SP     healthState          : 0x" + Integer.toHexString(healthState));
		System.out.println("SP     immuneSystemStrength : 0x" + Integer.toHexString(immuneSystemStrength));
		System.out.println("SP     mutationCount        : 0x" + Integer.toHexString(mutationCount));
		System.out.println("SP     mutationAmount       : 0x" + Integer.toHexString(mutationAmount));
		System.out.println("SP     minImmuneRange       : 0x" + Integer.toHexString(minImmuneRange));
		System.out.println("SP     maxImmuneRange       : 0x" + Integer.toHexString(maxImmuneRange));
	}

	public boolean equals(SangSongPacket other)
	{
		if(transmittingNodeNum  != other.transmittingNodeNum ) return false;
		if(sequenceNum          != other.sequenceNum         ) return false;
		if(songNum              != other.songNum             ) return false;
		if(healthState          != other.healthState         ) return false;
		if(immuneSystemStrength != other.immuneSystemStrength) return false;
		if(mutationCount        != other.mutationCount       ) return false;
		if(mutationAmount       != other.mutationAmount      ) return false;
		if(minImmuneRange       != other.minImmuneRange      ) return false;
		if(maxImmuneRange       != other.maxImmuneRange      ) return false;

		return super.equals(other);
	}
}

